[![PyPI Latest Release](https://img.shields.io/pypi/v/dash-grocery.svg)](https://pypi.org/project/dash-dash-grocery/)

# Dash Grocery

Dash Grocery is a Dash component library. The purpose of this package is to collect interesting and useful React projects to wrap. I'm excited to have the first release, PRs are welcome!

